CommentDumper class final Dumping Types

A class that dumps comments based on the CommentStyle.

Constructors

CommentDumper(CommentStyle style, int stepSize)
const

Properties

dumpsInline bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stepSize int
Factor that linearly increases the indentation level for all comments except the first one.
final
style CommentStyle
Style used to dump comments.
final

Methods

applyComments(String node, {required List<String> comments, required bool forceBlock, required int indent, required int offsetFromMargin}) String
Applies the comments of a dumped node.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited