ConcreteNode<T> class final Dumping Types

A shallow sandboxed dumpable view of a Dart type that is not an alias.

"Shallow" here just means only the top level object passed to this class is wrapped. For lists and maps, any nested object is implicitly is assumed to share the NodeStyle of the parent. For scalars, the NodeStyle has no effect.

Inheritance
Available extensions

Properties

alias String?
Alias name that references other nodes.
no setterinherited
anchor String?
Anchor name that allow other nodes to reference this node.
getter/setter pair
comments List<String>
Node's comments
finalinherited
dumpable → T
Object being dumped
final
hashCode int
The hash code for this object.
no setterinherited
isScalar bool
Whether the object should be treated as a scalar.
no setteroverride
nodeStyle NodeStyle
Style used to serialize the node within the YAML source string
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag ResolvedTag?
Tag directive describing how the node is represented natively.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withNodeTag({required TagShorthand localTag, GlobalTag? globalTag}) ConcreteNode<T>

Available on ConcreteNode<T>, provided by the Sandboxed extension

Updates the object's ResolvedTag to a localTag resolved to the specified globalTag. If globalTag is null, the object only has a generic local tag.
withVerbatimTag(VerbatimTag tag) ConcreteNode<T>

Available on ConcreteNode<T>, provided by the Sandboxed extension

Updates the object's ResolvedTag to a verbatim tag.

Operators

operator ==(Object other) bool
The equality operator.
inherited