CustomKind enum Custom Resolvers
Represents a node with a custom tag.
Values
- map → const CustomKind
-
Custom map-like structure that accepts keys.
- iterable → const CustomKind
-
Custom iterable that accepts elements.
- scalar → const CustomKind
-
A custom object that is not a CustomKind.map or CustomKind.iterable.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isGeneric → bool
-
Whether an object will be inferred as !!map or !!seq or !!str only when
the tag is non-specific.
no setteroverride
- isKnown → bool
-
Whether an object's kind was inferred from its tag.
no setteroverride
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CustomKind> - A constant List of the values in this enum, in order of their declaration.