CustomResolver<S, T> class sealed Resolvers Custom Resolvers

A resolver for any Dart object dumped as YAML.

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
kind CustomKind
NodeKind represent by this resolver.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

afterObject<R>() OnResolvedObject<Object, R>
Callback for the parser once the object R is resolved.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited