DumpableNode<T> class sealed Dumping Types

An object that can be dumped.

Implementers

Properties

alias String?
Alias name that references other nodes.
no setterinherited
anchor String?
Anchor name that allow other nodes to reference this node.
no setterinherited
comments List<String>
Node's comments
final
dumpable → T
Object being dumped
no setter
hashCode int
The hash code for this object.
no setterinherited
isScalar bool
Whether the object should be treated as a scalar.
no setter
nodeStyle NodeStyle
Style used to serialize the node within the YAML source string
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag ResolvedTag?
Tag directive describing how the node is represented natively.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited