GlobalTag<T> class final YamlDocument Types of Tags Declaring Tags in Code

Describes a tag shorthand notation for specifying node tags. It must begin with the %TAG directive.

`%TAG !yaml! tag:yaml.org,2002:`

# %TAG = directive
# !yaml! = shorthand
# tag:yaml.org,2002: = prefix
Inheritance
Implemented types

Constructors

GlobalTag.fromTagShorthand(TagHandle tagHandle, TagShorthand tag)
Creates a global tag whose prefix is a TagShorthand.
GlobalTag.fromTagUri(TagHandle handle, String uri)
Creates a global tag whose prefix is a valid tag uri
factory

Properties

content → T
finalinherited
hashCode int
The hash code for this object.
no setteroverride
name String
Name of the directive
no setteroverride
parameters List<String>
Parameters that describe the directive
no setteroverride
prefix String
Actual prefix of the tag. This should not be confused with the tagHandle which describes a compact way of representing the prefix. For a GlobalTag or a TagShorthand resolved to a GlobalTag, this is the full prefix aliased by the tagHandle. For an unresolved TagShorthand, this defaults to its tagHandle.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagHandle TagHandle
Prefix of the tag
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override