iterableDumper property

set iterableDumper (IterableDumper dumper)

Sets the internal Iterable to dumper.

NOTE: A NodeStyle.block iterable dumper should not be provided to a NodeStyle.flow map dumper. This results in invalid YAML since block nodes are not allowed in flow nodes. Use ObjectDumper or prefer calling initialize. Alternatively, never call this setter unless you are *EXTREMELY* sure the YAML will be valid.

Implementation

set iterableDumper(IterableDumper dumper) {
  if (_hasIterableDumper) return;
  _hasIterableDumper = true;
  _iterableDumper = dumper;
}