NodeKind.generic constructor
NodeKind.generic()
Represents a node with a non-specific tag whose kind will be determined by the parser.
Implementation
factory NodeKind.generic() = _GenericKind;
Represents a node with a non-specific tag whose kind will be determined by the parser.
factory NodeKind.generic() = _GenericKind;