NodeProperty class final Custom Resolvers

Node anchor and/or tag.

Inheritance

Constructors

NodeProperty(RuneOffset start, RuneOffset end, int? indentOnExit, {required bool spanMultipleLines, required String? anchor, required ResolvedTag? tag, required NodeKind kind, required CustomResolver<Object, Object?>? customResolver, RuneOffset? structuralOffset})

Properties

anchor String?
Node's anchor.
final
customResolver CustomResolver<Object, Object?>?
A custom resolver for a node.
final
hashCode int
The hash code for this object.
no setterinherited
indentOnExit int?
The current indent after all the properties have been parsed.
finalinherited
isAlias bool
Whether this property is an alias.
no setterinherited
isMultiline bool
Whether the property spanned multiple lines.
finalinherited
kind NodeKind
Kind of node being parsed
finalinherited
parsedAny bool
Whether any tag, anchor or alias was parsed.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span RuneSpan
Start RuneOffset (inclusive) and an end RuneOffset (exclusive).
finalinherited
structuralOffset RuneOffset?
Actual offset of the node this property belongs to when it's preceded by a block sequence or explicit key/value indicator.
finalinherited
tag ResolvedTag?
Node's resolved tag.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited