isGeneric property

  1. @override
bool isGeneric
final

Whether this is tag was explicit or assigned by the parser automatically after resolving a node and its tag.

Implementation

@override
final bool isGeneric;