suffix property
Represents the TagShorthand suffix resolved to GlobalTag prefix in a
YAML source string. Defaults to null if the Tag is a VerbatimTag
or a ContentResolver.
Implementation
@override
final TagShorthand suffix;
Represents the TagShorthand suffix resolved to GlobalTag prefix in a
YAML source string. Defaults to null if the Tag is a VerbatimTag
or a ContentResolver.
@override
final TagShorthand suffix;