verbatim property
Full representation of a tag. Any SpecificTag can be represented this way even if it is unresolved.
!<tag:yaml.org,2002:str> # Global Tag for strings
!<!foo> # Local Tag
Implementation
@override
final String verbatim;
Full representation of a tag. Any SpecificTag can be represented this way even if it is unresolved.
!<tag:yaml.org,2002:str> # Global Tag for strings
!<!foo> # Local Tag
@override
final String verbatim;