ObjectDumper class final Dumping Scalars Dumping Sequence Dumping Mapping

A class used to dump objects.

Inheritance

Constructors

ObjectDumper.compact()
Creates a resuable dumper that outputs a compact YAML string.
factory
ObjectDumper.of({bool unpackAliases = false, CommentStyle commentStyle = CommentStyle.block, int commentStepSize = 0, ScalarStyle scalarStyle = ScalarStyle.plain, bool forceScalarsInline = false, bool forceIterablesInline = false, bool forceMapsInline = false, NodeStyle mapStyle = NodeStyle.block, NodeStyle iterableStyle = NodeStyle.block, Object? mapper(Object? object)?})
Creates a reusable dumper.
factory

Properties

asLocalTag AsLocalTag
A callback for validating, tracking and normalizing a resolved tag.
finalinherited
commentDumper CommentDumper
Dumps comments associated with any node.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
iterableDumper IterableDumper
Dumps Iterables.
latefinalinherited
mapDumper MapDumper
Dumps Maps.
latefinalinherited
pushAnchor PushAnchor
A callback for pushing anchors.
finalinherited
readAnchor ConcreteNode<Object?>? Function(String anchor)
A callback for accessing aliases of an anchor.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalarDumper ScalarDumper
Dumps any object that is not a Map or Iterable.
latefinalinherited
unpackAliases bool
Whether aliases should be unpacked and dumped as the actual node.
finalinherited
unwrap Object? Function(Object? object)
Maps an object.
final

Methods

capturedProperties() ObjectProperties?
Anchors and tags captured when dumping objects after unpacking a ResolvedTag. The map with the GlobalTags must be modifiable.
override
dumpable(Object? object) DumpableNode<Object?>
Attempts to convert the object to a DumpableNode. Unpacks an Alias and return its true reference if unpackAliases is true.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onComplete() → void
Resets a dumper after an object has been dumped. Override and clean up your dumper's internal state.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited