ParsedProperty class sealed Custom Resolvers

A node's parsed property.

Implementers

Constructors

ParsedProperty.empty(RuneOffset start, RuneOffset end, int? indentOnExit, {required bool spanMultipleLines, required RuneOffset? structuralOffset})
factory
ParsedProperty.of(RuneOffset? structuralOffset, RuneOffset start, RuneOffset end, {required bool spanMultipleLines, required int? indentOnExit, required String? anchor, required ResolvedTag? tag, required NodeKind kind, required CustomResolver<Object, Object?>? customResolver})
Creates a wrapper that indicates the node's properties parsing call was just empty lines.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
indentOnExit int?
The current indent after all the properties have been parsed.
final
isAlias bool
Whether this property is an alias.
no setter
isMultiline bool
Whether the property spanned multiple lines.
final
kind NodeKind
Kind of node being parsed
final
parsedAny bool
Whether any tag, anchor or alias was parsed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
span RuneSpan
Start RuneOffset (inclusive) and an end RuneOffset (exclusive).
final
structuralOffset RuneOffset?
Actual offset of the node this property belongs to when it's preceded by a block sequence or explicit key/value indicator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited