Scalar<T> class final Introduction YamlSourceNodes

Any value that is not a Sequence or Mapping.

For equality, a scalar uses the inferred value T for maximum compatibility with Dart objects that can be scalars.

Inheritance
Available extensions

Constructors

Scalar(ScalarValue<T> _type, {required ScalarStyle scalarStyle, required NodeSpan span, required String? anchor, required ResolvedTag? tag})

Properties

alias String?
Alias name that references other nodes.
no setterinherited
anchor String?
Anchor name that allow other nodes to reference this node.
final
childOfKey YamlSourceNode?
Always null unless this value is a key.
getter/setter pairinherited
children List<YamlSourceNode>
Childred if this is a collection.
no setteroverride
hashCode int
The hash code for this object.
no setteroverride
isAlias bool
Whether the object is an alias.
no setteroverride
isCyclicRoot bool
Whether this is the first node in a cyclic linked-list.
getter/setter pairinherited
isTransversable bool
Whether the object is transversible by index/key or both. If true, this node is a collection.
no setteroverride
node → T
A native value represented by the parsed scalar.
no setteroverride
nodeStyle NodeStyle
Style used to serialize the node within the YAML source string
no setter
parent YamlSourceNode?
Direct ancestor.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalarStyle ScalarStyle
Style used to serialize the scalar. Can be degenerated to a block or flow too.
final
siblingLeft YamlSourceNode?
Node on the left if in a collection.
getter/setter pairinherited
siblingRight YamlSourceNode?
Node on the right if in a collection.
getter/setter pairinherited
span NodeSpan
Span within a YAML source.
final
tag ResolvedTag?
Tag directive describing how the node is represented natively.
final

Methods

cast<T extends YamlSourceNode>() → T

Available on YamlSourceNode, provided by the Cast extension

Casts a generic YamlSourceNode to a valid (and known) subtype
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override