ScalarDumper class final Dumping Scalars

A persistent dumper for scalars.

Mixed-in types

Constructors

ScalarDumper.classic(Compose onScalar, AsLocalTag asLocalTag, [bool inline = false])
Creates a ScalarDumper where empty strings are always dumped as null and aliases are compacted.
const
ScalarDumper.fineGrained({required bool replaceEmpty, required Compose onScalar, required AsLocalTag asLocalTag, ScalarStyle style = ScalarStyle.doubleQuoted, bool forceInline = false})
Creates a ScalarDumper.
const

Properties

asLocalTag AsLocalTag
Tracks the object and its properties.
final
defaultStyle ScalarStyle
Style to use when a block node is inserted into node
final
forceInline bool
Whether the scalar should be forced inline if a line break is seen.
final
hashCode int
The hash code for this object.
no setterinherited
onObject Compose
A helper function for composing a dumpable object.
final
replaceEmpty bool
Whether empty strings are dumped as null.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyBlock(String? tag, String? anchor, int nodeIndent, String node) String
Applies the tag and anchor in its own line just before the node. Apply to block collections only.
inherited
applyInline(String? tag, String? anchor, String node) String
Applies the node's properties inline. Apply to any scalars and flow collections.
inherited
dump(Object? scalar, {required int indent, int parentIndent = 0, required ScalarStyle? style}) DumpedScalar
Dumps a scalar.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited