SpecificTag<T> class sealed Types of Tags Declaring Tags in Code

Represents a Tag that can be represented as a GlobalTag or TagShorthand. YAML requires a parsed node to be resolved as a SpecificTag or be represented as is as a VerbatimTag.

Inheritance
Implementers

Properties

content → T
final
hashCode int
The hash code for this object.
no setterinherited
prefix String
Actual prefix of the tag. This should not be confused with the tagHandle which describes a compact way of representing the prefix. For a GlobalTag or a TagShorthand resolved to a GlobalTag, this is the full prefix aliased by the tagHandle. For an unresolved TagShorthand, this defaults to its tagHandle.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagHandle TagHandle
Prefix of the tag
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited