prefix property

String get prefix

Actual prefix of the tag. This should not be confused with the tagHandle which describes a compact way of representing the prefix. For a GlobalTag or a TagShorthand resolved to a GlobalTag, this is the full prefix aliased by the tagHandle. For an unresolved TagShorthand, this defaults to its tagHandle.

Implementation

String get prefix;