TagHandle class final Introduction to Tags Types of Tags Declaring Tags in Code

Represents a prefix for any Tag declared in YAML

Constructors

TagHandle.named(String name)
name is a valid non-empty tag uri. Any !, {, }, [, or ] must be encoded as 2 hex characters preceded by the %.
factory
TagHandle.primary()
!
TagHandle.secondary()
!!

Properties

handle String
Prefix denoting the tag handle
final
handleVariant TagHandleVariant
Type of tag handle
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override