TagShorthand class final Types of Tags Declaring Tags in Code

A tag shorthand for a node that may (not) be resolved to a GlobalTag.

Inheritance

Constructors

TagShorthand.fromTagUri(TagHandle tagHandle, String suffix)
Creates a local tag with the tagHandle and suffix.
TagShorthand.named(String name, String suffix)
Creates a local tag with the named tag handle prefix ![name]!.
TagShorthand.primary(String suffix)
Creates a local tag with the primary tag handle prefix !.
TagShorthand.secondary(String suffix)
Creates a local tag with the secondary tag handle prefix !!.

Properties

content String
finalinherited
hashCode int
The hash code for this object.
no setteroverride
isNonSpecific bool
Indicates a tag with with a single ! prefix and no content.
no setter
prefix String
Actual prefix of the tag. This should not be confused with the tagHandle which describes a compact way of representing the prefix. For a GlobalTag or a TagShorthand resolved to a GlobalTag, this is the full prefix aliased by the tagHandle. For an unresolved TagShorthand, this defaults to its tagHandle.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tagHandle TagHandle
Prefix of the tag
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override