VerbatimTag class final Types of Tags Declaring Tags in Code

Represents a tag explicitly declared in its raw form. Never resolved to GlobalTag

Inheritance

Constructors

VerbatimTag.fromTagShorthand(TagShorthand tag)
Creates a verbatim tag from a local tag.
factory
VerbatimTag.fromTagUri(String uri)
Creates a verbatim tag from a valid tag uri. uri must start with the global tag uri scheme tag:. Any non-uri characters present will be normalized.
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
isGeneric bool
Whether this is tag was explicit or assigned by the parser automatically after resolving a node and its tag.
no setteroverride
prefix String
Actual prefix of the tag. This should not be confused with the tagHandle which describes a compact way of representing the prefix. For a GlobalTag or a TagShorthand resolved to a GlobalTag, this is the full prefix aliased by the tagHandle. For an unresolved TagShorthand, this defaults to its tagHandle.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suffix TagShorthand?
Represents the TagShorthand suffix resolved to GlobalTag prefix in a YAML source string. Defaults to null if the Tag is a VerbatimTag or a ContentResolver.
no setterinherited
tagHandle TagHandle
Prefix of the tag
no setteroverride
verbatim String
Full representation of a tag. Any SpecificTag can be represented this way even if it is unresolved.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override