YamlCollectionKind enum Custom Resolvers

Represents a node with(out) a tag that contains other nodes.

Inheritance
Implemented types
Available extensions

Values

set → const YamlCollectionKind

Set or Sequence with unique elements. This could also represent a YamlCollectionKind.orderedMap or YamlCollectionKind.mapping.

sequence → const YamlCollectionKind

Normal Sequence or List.

orderedMap → const YamlCollectionKind

YamlCollectionKind.mapping or a Sequence/List of YamlCollectionKind.mapping.

mapping → const YamlCollectionKind

Mapping or Map.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isGeneric bool
Whether an object will be inferred as !!map or !!seq or !!str only when the tag is non-specific.
no setteroverride
isKnown bool
Whether an object's kind was inferred from its tag.
no setteroverride
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<YamlCollectionKind>
A constant List of the values in this enum, in order of their declaration.