YamlDumper class abstract

A yaml dumper.

Implementers

Constructors

YamlDumper({required bool unpackAliases, required PushAnchor pushAnchor, required ConcreteNode<Object?>? readAnchor(String anchor), required AsLocalTag asLocalTag, CommentDumper? commentDumper})

Properties

asLocalTag AsLocalTag
A callback for validating, tracking and normalizing a resolved tag.
final
commentDumper CommentDumper
Dumps comments associated with any node.
final
hashCode int
The hash code for this object.
no setterinherited
iterableDumper IterableDumper
Dumps Iterables.
latefinal
mapDumper MapDumper
Dumps Maps.
latefinal
pushAnchor PushAnchor
A callback for pushing anchors.
final
readAnchor ConcreteNode<Object?>? Function(String anchor)
A callback for accessing aliases of an anchor.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scalarDumper ScalarDumper
Dumps any object that is not a Map or Iterable.
latefinal
unpackAliases bool
Whether aliases should be unpacked and dumped as the actual node.
final

Methods

capturedProperties() ObjectProperties?
Anchors and tags captured when dumping objects after unpacking a ResolvedTag. The map with the GlobalTags must be modifiable.
dumpable(Object? object) DumpableNode<Object?>
Attempts to convert the object to a DumpableNode. Unpacks an Alias and return its true reference if unpackAliases is true.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onComplete() → void
Resets a dumper after an object has been dumped. Override and clean up your dumper's internal state.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited