dumpable method

DumpableNode<Object?> dumpable(
  1. Object? object
)

Attempts to convert the object to a DumpableNode. Unpacks an Alias and return its true reference if unpackAliases is true.

If your object has a special steps before it can be a dumpable

Implementation

DumpableNode<Object?> dumpable(Object? object) => dumpableType(object);