YamlScalarKind enum Custom Resolvers
Represents any node with a scalar tag.
Values
- string → const YamlScalarKind
- stringToType → const YamlScalarKind
-
String that is mapped to a type after it has been buffered.
- nullString → const YamlScalarKind
-
Null.
- booleanString → const YamlScalarKind
-
bool.
- integer → const YamlScalarKind
-
int.
- float → const YamlScalarKind
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isGeneric → bool
-
Whether an object will be inferred as !!map or !!seq or !!str only when
the tag is non-specific.
no setteroverride
- isKnown → bool
-
Whether an object's kind was inferred from its tag.
no setteroverride
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
YamlScalarKind> - A constant List of the values in this enum, in order of their declaration.