YamlSourceNode class sealed Introduction YamlSourceNodes

A node parsed from a YAML source string.

This node represents a directed graph that can used to iterate the entire YAML tree generated by the parser before any properties and styles are stripped. Having this single node guarantees full access to the tree irrespective of its location.

This node also acts as a compatibility layer between the parsed CompactYamlNode and a Dart type. The object is always a Dart type or a type inferred from a ScalarResolver when it comes to scalars.

  • Scalar of 4 has no difference when compared to 4
  • Sequence or Map of values will be equal to the same List or Map declared in Dart.
Mixed-in types
Implementers
Available extensions

Properties

alias String?
Alias name that references other nodes.
no setterinherited
anchor String?
Anchor name that allow other nodes to reference this node.
no setterinherited
childOfKey YamlSourceNode?
Always null unless this value is a key.
getter/setter pairinherited
children List<YamlSourceNode>
Childred if this is a collection.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isAlias bool
Whether the object is an alias.
no setter
isCyclicRoot bool
Whether this is the first node in a cyclic linked-list.
getter/setter pairinherited
isTransversable bool
Whether the object is transversible by index/key or both. If true, this node is a collection.
no setterinherited
node Object?
Built-in or custom Dart type represented by this object.
no setter
nodeStyle NodeStyle
Style used to serialize the node within the YAML source string
no setterinherited
parent YamlSourceNode?
Direct ancestor.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siblingLeft YamlSourceNode?
Node on the left if in a collection.
getter/setter pairinherited
siblingRight YamlSourceNode?
Node on the right if in a collection.
getter/setter pairinherited
span NodeSpan
Span within a YAML source.
no setter
tag ResolvedTag?
Tag directive describing how the node is represented natively.
no setterinherited

Methods

cast<T extends YamlSourceNode>() → T

Available on YamlSourceNode, provided by the Cast extension

Casts a generic YamlSourceNode to a valid (and known) subtype
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited