CustomTriggers class Resolvers Custom Resolvers Bytes To Scalar Object from Sequence Object from Mapping
A class with callbacks to some of the inner workings of the parser.
- Implementers
Constructors
-
CustomTriggers({List<
ScalarResolver< ? resolvers, AdvancedResolvers? advancedResolvers})Object?> >
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onCustomResolver(
TagShorthand localTag) → CustomResolver< Object, Object?> ? - Obtains a custom resolver that instantiates custom object delegates. Called before onScalarResolver when a local tag is being resolved to a global tag.
-
onDefaultMapping<
K, V, M> () → ObjectFromMap< K, V, M> ? - Triggered when the parser requires a generic mapping delegate when no tags are present. This could be used to return custom objects for top-level and nested mappings if paired correctly with onParsedKey.
-
onDefaultScalar<
S> () → ObjectFromScalarBytes< S> ? -
Triggered when the parser requires a generic scalar delegate when no tags
are present. This is never called if the parser can accurately default
the scalar to
nullahead of time. -
onDefaultSequence<
E, S> () → ObjectFromIterable< E, S> ? - Triggered when the parser requires a generic sequence delegate when no tags are present.
-
onDocumentStart(
int index) → void - Triggered when the parser starts parsing a document within a yaml source string.
-
onParsedKey(
Object? key) → void - Triggered when the parser parses a valid mapping key and always before its value is parsed.
-
onScalarResolver(
TagShorthand localTag) → ResolverCreator< Object?> ? -
Obtains a scalar resolver that maps a scalar's content to a custom type.
Called after onCustomResolver when a local tag is being resolved to a
global tag only if it returns
null. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited