IterableDumper class final Dumping Sequence
A dumper for an Iterable.
- Mixed-in types
Constructors
- IterableDumper.block({required ScalarDumper scalarDumper, required CommentDumper commentDumper, required Compose onObject, required PushAnchor pushAnchor, required AsLocalTag asLocalTag, bool inlineNestedFlowIterable = false, bool inlineNestedFlowMap = false})
- IterableDumper.flow({required bool preferInline, required ScalarDumper scalarDumper, required CommentDumper commentDumper, required Compose onObject, required PushAnchor pushAnchor, required AsLocalTag asLocalTag, bool inlineMap = true})
Properties
- asLocalTag → AsLocalTag
-
A callback for validating, tracking and normalizing a resolved tag.
final
- canApplyTrailingComments → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineNestedIterable → bool
-
Whether nested flow iterables are inlined.
final
- inlineNestedMap → bool
-
Whether nested flow maps are inlined.
final
- isBlockDumper → bool
-
no setter
- iterableStyle → NodeStyle
-
final
- mapDumper ← MapDumper
-
Sets the internal MapDumper to
dumper.no getter - onObject → Compose
-
A helper function for composing a dumpable object.
final
- pushAnchor → PushAnchor
-
A callback for pushing anchors.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scalarDumper → ScalarDumper
-
Dumper for scalars.
final
Methods
-
applyBlock(
String? tag, String? anchor, int nodeIndent, String node) → String -
Applies the
tagandanchorin its own line just before thenode. Apply to block collections only.inherited -
applyInline(
String? tag, String? anchor, String node) → String -
Applies the node's properties inline. Apply to any scalars and flow
collections.
inherited
-
dump(
ConcreteNode< Iterable< iterable, int indent) → DumpedCollectionObject?> > -
Dumps an
iterablewith the providedindent. -
dumpIterableLike<
T> (T object, {required Iterable< Object?> expand(T object), required int indent, ResolvedTag? tag, String? anchor, List<String> comments = const []}) → DumpedCollection -
Dumps a custom
objectas an Iterable. -
formatBlockEntry(
String entry, String indentation, {required bool isNotFirst}) → String -
Formats a block map/iterable entry before it is buffered.
inherited
-
formatFlowEntry(
String entry, String indentation, {required bool preferInline, required bool lastHadTrailing, required bool isNotFirst}) → String -
Formats a flow map/iterable entry before it is buffered.
inherited
-
initialize(
) → void -
Ensures the internal
_mapDumperwas set. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited