MapDumper class final Dumping Mapping
A dumper for a Map.
- Mixed-in types
Constructors
- MapDumper.block({required ScalarDumper scalarDumper, required CommentDumper commentDumper, required Compose onObject, required PushAnchor pushAnchor, required AsLocalTag asLocalTag, bool inlineNestedFlowIterable = false, bool inlineNestedFlowMap = false})
- Dumper for block maps.
- MapDumper.flow({required bool preferInline, required ScalarDumper scalarDumper, required CommentDumper commentDumper, required Compose onObject, required PushAnchor pushAnchor, required AsLocalTag asLocalTag, bool inlineIterable = true})
- Dumper for flow maps.
Properties
- asLocalTag → AsLocalTag
-
A callback for validating, tracking and normalizing a resolved tag.
final
- canApplyTrailingComments → bool
-
Whether this map accepts trailing comments.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inlineNestedIterable → bool
-
Whether nested flow iterables are inlined.
final
- inlineNestedMap → bool
-
Whether nested flow maps are inlined.
final
- isBlockDumper → bool
-
no setter
- iterableDumper ← IterableDumper
-
Sets the internal Iterable to
dumper.no getter - mapStyle → NodeStyle
-
Map style
final
- onObject → Compose
-
A helper function for composing a dumpable object.
final
- pushAnchor → PushAnchor
-
A callback for pushing anchors.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scalarDumper → ScalarDumper
-
Dumper for scalars.
final
Methods
-
applyBlock(
String? tag, String? anchor, int nodeIndent, String node) → String -
Applies the
tagandanchorin its own line just before thenode. Apply to block collections only.inherited -
applyInline(
String? tag, String? anchor, String node) → String -
Applies the node's properties inline. Apply to any scalars and flow
collections.
inherited
-
dump(
ConcreteNode< Map< mapEntries, int indent) → DumpedCollectionObject?, Object?> > -
Dumps a sequence of
mapEntrieswith the providedindentof the map. -
dumpMapLike<
T> (T object, {required Map< Object?, Object?> expand(T object), required int indent, ResolvedTag? tag, String? anchor, List<String> comments = const []}) → DumpedCollection -
Dumps an
objectas a Map. -
formatBlockEntry(
String entry, String indentation, {required bool isNotFirst}) → String -
Formats a block map/iterable entry before it is buffered.
inherited
-
formatFlowEntry(
String entry, String indentation, {required bool preferInline, required bool lastHadTrailing, required bool isNotFirst}) → String -
Formats a flow map/iterable entry before it is buffered.
inherited
-
initialize(
) → void -
Ensures the internal
_iterableDumperwas set. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited