NodeKind class sealed Custom Resolvers
Represents the kind of node to be parsed.
Constructors
- NodeKind.generic()
-
Represents a node with a non-specific tag whose kind will be determined
by the parser.
factory
- NodeKind.unknown()
-
Represents a node whose kind could not be determined.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGeneric → bool
-
Whether an object will be inferred as !!map or !!seq or !!str only when
the tag is non-specific.
no setter
- isKnown → bool
-
Whether an object's kind was inferred from its tag.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited