NodeSpan class sealed
Offset information for a parsed YAML node.
Always represents the start of the first parsable character of the node. For top-level nodes, this doesn't include document level comments.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeEnd → RuneOffset
-
Exclusive end offset of the node's meaningful content.
no setter
- nodeStart → RuneOffset
-
Actual start offset of the node.
no setter
- propertySpan → RuneSpan?
-
Span information for a node's property. This includes the
*of an alias,!!of a tag and&of an anchor.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- structuralOffset → RuneOffset?
-
Actual start offset when the current node is part of a node that allows
arbitrary use of YAML indicators to demarcate it structure. For the
parser, this is the node's first parsable content.
no setter
Methods
-
end(
) → RuneOffset - Exclusive end offset of the node.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited