PropertyDumper mixin
Helper for dumping node properties.
- Mixin applications
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
applyBlock(
String? tag, String? anchor, int nodeIndent, String node) → String -
Applies the
tagandanchorin its own line just before thenode. Apply to block collections only. -
applyInline(
String? tag, String? anchor, String node) → String - Applies the node's properties inline. Apply to any scalars and flow collections.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited