ReservedDirective class sealed YamlDocument
Represents any unknown directive which YAML, by default, reserves for
future use. Typically any that is not a YamlDirective or a GlobalTag.
- Implemented types
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
Name of the directive
final
-
parameters
→ List<
String> -
Parameters that describe the directive
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override