ResolvedTag class sealed Custom Resolvers
Represents any Tag resolved to a GlobalTag prefix or declared in verbatim as a VerbatimTag
- Inheritance
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGeneric → bool
-
Whether this is tag was explicit or assigned by the parser automatically
after resolving a node and its tag.
no setter
- prefix → String
-
Actual prefix of the tag. This should not be confused with the
tagHandle which describes a compact way of representing the prefix. For
a GlobalTag or a TagShorthand resolved to a GlobalTag, this is the
full prefix aliased by the tagHandle. For an unresolved TagShorthand,
this defaults to its tagHandle.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffix → TagShorthand?
-
Represents the TagShorthand suffix resolved to GlobalTag prefix in a
YAMLsource string. Defaults tonullif the Tag is a VerbatimTag or a ContentResolver.no setter - tagHandle → TagHandle
-
Prefix of the tag
no setterinherited
- verbatim → String
-
Full representation of a tag. Any SpecificTag can be represented this
way even if it is unresolved.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited