RootNode<T> typedef
RootNode<T> = ({Map<String, T> anchors, List<YamlComment> comments, T root})
Contains information about the document's root yaml node and any comments parsed within the document. YAML spec bluntly states that a comment should not be associated with a node.
Implementation
typedef RootNode<T> = ({
T root,
Map<String, T> anchors,
List<YamlComment> comments,
});