TagHandleVariant enum
Types of a TagHandle
Values
- primary → const TagHandleVariant
-
Normally used as a prefix for most TagShorthands and all non-specific local tags
const TagHandleVariant('!') - secondary → const TagHandleVariant
-
Prefix for tags that resolve to
tag:yaml.org,2002:unless overriden by the%TAGdirective globally.const TagHandleVariant('!!') - named → const TagHandleVariant
-
Prefix which supports a custom name. Must provide trailing
!to indicate the end of the name.const TagHandleVariant('')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TagHandleVariant> - A constant List of the values in this enum, in order of their declaration.