TagInfo<T> mixin
Custom Resolvers
Object from Sequence
Helper mixin that normalizes the local tag information assigned to an
ObjectDelegate.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasProperty → bool
-
Whether any properties are present
no setterinherited
- property → ParsedProperty?
-
Property obtained from a YAML source string if present.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
localTagInfo(
) → ({GlobalTag? globalTag, TagShorthand suffix})? -
Obtains the resolved local tag information associated with each object.
Always returns
nullfor any alias or object having a VerbatimTag. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parsed(
) → T -
Resolves the object
T.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited